summaryrefslogtreecommitdiffstats
path: root/src/lib.rs
diff options
context:
space:
mode:
Diffstat (limited to 'src/lib.rs')
-rw-r--r--src/lib.rs8
1 files changed, 5 insertions, 3 deletions
diff --git a/src/lib.rs b/src/lib.rs
index ae02c36..986f36a 100644
--- a/src/lib.rs
+++ b/src/lib.rs
@@ -6,7 +6,7 @@
//! - Environment variables
//! - Another Config instance
//! - Remote configuration: etcd, Consul
//! - Files: TOML, JSON, YAML, HJSON, INI, RON
//! - Manual, programmatic override (via a `.set` method on the Config instance)
//!
//! Additionally, Config supports:
@@ -24,8 +24,7 @@
#[macro_use]
extern crate serde;
-#[cfg(test)]
-#[macro_use]
+#[cfg(any(test, feature = "json5"))]
extern crate serde_derive;
extern crate nom;
@@ -51,6 +50,9 @@ extern crate ini;
#[cfg(feature = "ron")]
extern crate ron;
+#[cfg(feature = "json5")]
+extern crate json5_rs;
+
mod builder;
mod config;
mod de;
@@ -6,7 +6,7 @@
//! - Another Config instance
//! - Remote configuration: etcd, Consul
-//! - Files: TOML, JSON, YAML, HJSON, INI, RON
+//! - Files: TOML, JSON, YAML, HJSON, INI, RON, JSON5
//! - Manual, programmatic override (via a `.set` method on the Config instance)
//!